==> seedsui-react-2.6.2.tgz: package/es/Ticket/Ticket.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Ticket = function (_Component) {
  _inherits(Ticket, _Component);

  function Ticket(props) {
    _classCallCheck(this, Ticket);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Ticket.prototype.render = function render() {
    var _props = this.props,
        className = _props.className,
        legend = _props.legend,
        legendStyle = _props.legendStyle,
        legendClassName = _props.legendClassName,
        children = _props.children,
        containerStyle = _props.containerStyle,
        containerClassName = _props.containerClassName,
        others = _objectWithoutProperties(_props, ['className', 'legend', 'legendStyle', 'legendClassName', 'children', 'containerStyle', 'containerClassName']);

    return React.createElement(
      'div',
      _extends({ className: 'ticket' + (className ? ' ' + className : '') }, others),
      React.createElement(
        'div',
        { className: 'ticket-legend' + (legendClassName ? ' ' + legendClassName : ''), style: legendStyle },
        legend
      ),
      React.createElement(
        'div',
        { className: 'ticket-container' + (containerClassName ? ' ' + containerClassName : ''), style: containerStyle },
        children
      )
    );
  };

  return Ticket;
}(Component);

export { Ticket as default };
Ticket.propTypes = process.env.NODE_ENV !== "production" ? {
  className: PropTypes.string,
  legendStyle: PropTypes.object,
  legendClassName: PropTypes.string,
  legend: PropTypes.node,
  containerStyle: PropTypes.object,
  containerClassName: PropTypes.string,
  children: PropTypes.node
} : {};

==> seedsui-react-3.7.9.tgz: package/es/Ticket/Ticket.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';

var Ticket = function (_Component) {
  _inherits(Ticket, _Component);

  function Ticket(props) {
    _classCallCheck(this, Ticket);

    return _possibleConstructorReturn(this, _Component.call(this, props));
  }

  Ticket.prototype.render = function render() {
    var _this2 = this;

    var _props = this.props,
        legend = _props.legend,
        _props$legendAttribut = _props.legendAttribute,
        legendAttribute = _props$legendAttribut === undefined ? {} : _props$legendAttribut,
        _props$contentAttribu = _props.contentAttribute,
        contentAttribute = _props$contentAttribu === undefined ? {} : _props$contentAttribu,
        children = _props.children,
        others = _objectWithoutProperties(_props, ['legend', 'legendAttribute', 'contentAttribute', 'children']);

    return React.createElement(
      'div',
      _extends({ ref: function ref(el) {
          _this2.$el = el;
        } }, others, { className: 'ticket' + (others.className ? ' ' + others.className : '') }),
      React.createElement(
        'div',
        _extends({}, legendAttribute, { className: 'ticket-legend' + (legendAttribute.className ? ' ' + legendAttribute.className : '') }),
        legend
      ),
      React.createElement(
        'div',
        _extends({}, contentAttribute, { className: 'ticket-content' + (contentAttribute.className ? ' ' + contentAttribute.className : '') }),
        children
      )
    );
  };

  return Ticket;
}(Component);

export { Ticket as default };
Ticket.propTypes = process.env.NODE_ENV !== "production" ? {
  legend: PropTypes.node,
  legendAttribute: PropTypes.object,
  contentAttribute: PropTypes.object,
  children: PropTypes.node
} : {};
